==> kmp-authentication-impl-0.4.0-sources.jar: commonMain/io/privy/auth/internal/RealAuthRepository.kt <==
package io.privy.auth.internal

import io.ktor.resources.Resource
import io.privy.auth.AuthRepository
import io.privy.auth.AuthenticationException
import io.privy.auth.LoginType
import io.privy.auth.LoginType.CustomAccessToken
import io.privy.auth.UpdateAccountType
import io.privy.auth.oAuth.OAuthInitRequest
import io.privy.auth.oAuth.OAuthInitResponse
import io.privy.auth.oAuth.OAuthProvider
import io.privy.auth.otp.OtpRequestType
import io.privy.auth.session.AuthSessionResponseDeserializer
import io.privy.auth.session.internal.AuthSessionResponse
import io.privy.auth.session.internal.MapRawAuthSessionResponseToAuthSessionResponse
import io.privy.auth.session.internal.toInternalPrivyUser
import io.privy.auth.siwe.toInternalSiweMessage
import io.privy.auth.siwe.GenerateSiweMessageResponse
import io.privy.auth.siwe.InternalSiweMessage
import io.privy.auth.siwe.SiweLoginParams
import io.privy.logging.PrivyLogger
import io.privy.network.ApiResult
import io.privy.network.AuthType
import io.privy.network.KtorWrapper
import io.privy.network.map
import kotlinx.serialization.Serializable
import me.tatarka.inject.annotations.Inject

@Inject
public class RealAuthRepository(
  private val ktorWrapper: KtorWrapper,
  private val privyLogger: PrivyLogger,
  private val authSessionResponseDeserializer: AuthSessionResponseDeserializer,
  private val mapRawAuthSessionResponseToAuthSessionResponse:
        MapRawAuthSessionResponseToAuthSessionResponse,
) : AuthRepository {
  override suspend fun authenticate(loginType: LoginType): ApiResult<AuthSessionResponse> {
    val authenticateRequest = AuthenticateResource(loginTypeApiPath = loginType.apiPath())

    val authenticateResponse: ApiResult<String> =
        ktorWrapper.postResult(
            resource = authenticateRequest,
            body = loginType.requestBody(),
            authType = AuthType.None,
        )

    return convertAuthResponseToInternalSession(
        authResponse = authenticateResponse,
        loginMethod = loginType.toLoginMethod(),
    )
  }

    override suspend fun generateOAuthUrl(
        oAuthInitRequest: OAuthInitRequest
    ): ApiResult<OAuthInitResponse> {
        return ktorWrapper
            .postResult<OauthInitResource, Map<String, String>, OAuthInitResponse>(
                resource = OauthInitResource,
                body = mapOf(
                    "provider" to oAuthInitRequest.provider.toRequestBody(),
                    "redirect_to" to oAuthInitRequest.redirectUri,
                    "code_challenge" to oAuthInitRequest.codeChallenge,
                    "state_code" to oAuthInitRequest.stateCode
                ),
                authType = AuthType.None
            )
    }


    override suspend fun link(loginType: LoginType, authToken: String): ApiResult<InternalPrivyUser> {
    return ktorWrapper
        .postResult<LinkAccountResource, Map<String, String>, String>(
            resource = LinkAccountResource(loginTypeApiPath = loginType.apiPath()),
            body = loginType.requestBody(),
            authType = AuthType.Authorization(accessToken = authToken),
        )
        .map { jsonResponse ->
          authSessionResponseDeserializer.deserializeRawUser(jsonResponse = jsonResponse)
        }
        .map { it.toInternalPrivyUser() }
  }

  override suspend fun update(
    accountType: UpdateAccountType,
    authToken: String
  ): ApiResult<InternalPrivyUser> {
    return ktorWrapper
      .postResult<UpdateAccountResource, Map<String, String>, String>(
        resource = UpdateAccountResource(updateAccountApiPath = accountType.apiPath()),
        body = accountType.requestBody(),
        authType = AuthType.Authorization(accessToken = authToken),
      )
      .map { jsonResponse ->
        authSessionResponseDeserializer.deserializeRawUser(jsonResponse = jsonResponse)
      }
      .map { it.toInternalPrivyUser() }
  }

  override suspend fun generateSiweMessage(walletAddress: String): ApiResult<InternalSiweMessage> {

    return ktorWrapper
        .postResult<SiweInitResource, Map<String, String>, GenerateSiweMessageResponse>(
            resource = SiweInitResource,
            body = mapOf("address" to walletAddress),
            authType = AuthType.None,
        )
        .map { it.toInternalSiweMessage() }
  }

  override suspend fun refreshSession(
      authToken: String,
      refreshToken: String,
      currentLoginMethod: LoginMethod,
  ): ApiResult<AuthSessionResponse> {
    val refreshResponse: ApiResult<String> =
        ktorWrapper.postResult(
            resource = RefreshSessionResource,
            body = mapOf("refresh_token" to refreshToken),
            authType = AuthType.Authorization(accessToken = authToken),
        )

    return convertAuthResponseToInternalSession(
        authResponse = refreshResponse,
        loginMethod = currentLoginMethod,
    )
  }

  override suspend fun refreshUser(authToken: String): ApiResult<InternalPrivyUser> {
    return ktorWrapper
        .getResult<RefreshUserResource, String>(
            resource = RefreshUserResource,
            authType = AuthType.Authorization(accessToken = authToken),
        )
        .map { jsonResponse ->
          privyLogger.internal("users/me response:\n$jsonResponse")
          authSessionResponseDeserializer.deserializeUser(jsonResponse = jsonResponse)
        }
        .map { it.user.toInternalPrivyUser() }
  }

  private fun convertAuthResponseToInternalSession(
      authResponse: ApiResult<String>,
      loginMethod: LoginMethod
  ): ApiResult<AuthSessionResponse> {
    return authResponse.map { jsonResponse ->
          privyLogger.internal("Authenticate API raw JSON response:\n$jsonResponse")

          authSessionResponseDeserializer.deserialize(jsonResponse = jsonResponse)
        }
        .map {
          privyLogger.internal("Authenticate API response: $it")

          mapRawAuthSessionResponseToAuthSessionResponse(
            rawAuthSessionResponse = it,
            loginMethod = loginMethod,
          )
        }
  }

  override suspend fun sendOtp(otpRequestType: OtpRequestType): ApiResult<Unit> {
    val sendOtpRequest = SendOtpResource(otpTypeApiPath = otpRequestType.apiPath())

    val sendOtpResponse: ApiResult<OtpInitResponse> =
        ktorWrapper.postResult(
            resource = sendOtpRequest,
            body = otpRequestType.requestBody(),
            authType = AuthType.None,
        )

    return when (sendOtpResponse) {
      // resurface underlying error
      is ApiResult.Error -> sendOtpResponse
      // translate success response
      is ApiResult.Success -> {
        if (sendOtpResponse.value.success) {
          ApiResult.Success(Unit)
        } else {
          // API should never return success == false, but just in case
          ApiResult.Error.GenericError(
            exception = AuthenticationException("Error sending OTP."),
            humanReadableMessage = "Error sending OTP."
          )
        }
      }
    }
  }
}

private fun LoginType.toLoginMethod(): LoginMethod {
  return when (this) {
    is LoginType.CustomAccessToken -> LoginMethod.CustomAccessToken
    is LoginType.Sms -> LoginMethod.Sms
    is LoginType.Email -> LoginMethod.Email
    is LoginType.Siwe -> LoginMethod.Siwe
    is LoginType.OAuth -> LoginMethod.Oauth

  }
}

@Resource("{otpTypeApiPath}/init")
private class SendOtpResource(
    val otpTypeApiPath: String,
)

@Resource("{loginTypeApiPath}/authenticate")
private class AuthenticateResource(
    val loginTypeApiPath: String,
)

@Resource("{loginTypeApiPath}/link")
private class LinkAccountResource(
    val loginTypeApiPath: String,
)

@Resource("{updateAccountApiPath}/update")
private class UpdateAccountResource(
  val updateAccountApiPath: String,
)

@Resource("siwe/init") private data object SiweInitResource

@Resource("sessions") private data object RefreshSessionResource

@Resource("users/me") private data object RefreshUserResource

@Resource("oauth/init") private data object OauthInitResource

private fun LoginType.apiPath(): String {
    return when (this) {
        is CustomAccessToken -> "custom_jwt_account"
        is LoginType.Sms -> "passwordless_sms"
        is LoginType.Email -> "passwordless"
        is LoginType.Siwe -> "siwe"
        is LoginType.OAuth -> "oauth"
    }
}

private fun UpdateAccountType.apiPath(): String {
  return when (this) {
    is UpdateAccountType.Email -> "passwordless"
    is UpdateAccountType.Sms -> "passwordless_sms"
  }
}

private fun LoginType.requestBody(): Map<String, String> {
    return when (this) {
        is CustomAccessToken -> mapOf("token" to this.token)
        is LoginType.Sms -> mapOf("phoneNumber" to this.phoneNumber, "code" to this.code)
        is LoginType.Email -> mapOf("email" to this.emailAddress, "code" to this.code)
        is LoginType.Siwe -> params.toRequestBody()
        is LoginType.OAuth ->
            mapOf(
                "authorization_code" to authorizationCode,
                "code_verifier" to codeVerifier,
                "state_code" to stateCode
            )
    }
}

private fun UpdateAccountType.requestBody(): Map<String, String> {
  return when (this) {
    is UpdateAccountType.Email -> mapOf(
      "oldAddress" to this.oldEmail,
      "newAddress" to this.newEmail,
      "code" to this.code
    )
      is UpdateAccountType.Sms -> mapOf(
          "old_phone_number" to this.oldPhoneNumber,
          "new_phone_number" to this.newPhoneNumber,
          "code" to this.code
    )
  }
}

private fun OtpRequestType.apiPath(): String {
  return when (this) {
    is OtpRequestType.Email -> "passwordless"
    is OtpRequestType.Phone -> "passwordless_sms"
  }
}

private fun OtpRequestType.requestBody(): Map<String, String> {
  return when (this) {
    is OtpRequestType.Email -> mapOf("email" to this.email)
    is OtpRequestType.Phone -> mapOf("phoneNumber" to this.phone)
  }
}

private fun SiweLoginParams.toRequestBody(): Map<String, String> {
  val body = mutableMapOf("message" to message, "signature" to signature, "chainId" to chainId)
  walletClientType?.let { body["walletClientType"] = it.toString() }
  connectorType?.let { body["connectorType"] = it }
  return body
}

private fun OAuthProvider.toRequestBody(): String = when (this) {
    OAuthProvider.Google -> "google"
    OAuthProvider.Twitter -> "twitter"
    OAuthProvider.Discord -> "discord"
}

@Serializable private data class OtpInitResponse(val success: Boolean)

==> kmp-authentication-impl-0.6.0-sources.jar: commonMain/io/privy/auth/internal/RealAuthRepository.kt <==
package io.privy.auth.internal

import io.ktor.resources.Resource
import io.privy.auth.AuthRepository
import io.privy.auth.AuthenticationException
import io.privy.auth.LoginType
import io.privy.auth.LoginType.CustomAccessToken
import io.privy.auth.UpdateAccountType
import io.privy.auth.oAuth.OAuthInitRequest
import io.privy.auth.oAuth.OAuthInitResponse
import io.privy.auth.oAuth.OAuthProvider
import io.privy.auth.otp.OtpRequestType
import io.privy.auth.passkey.ApiAuthenticationOptionsResponse
import io.privy.auth.passkey.ApiRegistrationOptionsResponse
import io.privy.auth.passkey.AuthenticationOptions
import io.privy.auth.passkey.PasskeyAuthenticateRequest
import io.privy.auth.passkey.PasskeyRegisterRequest
import io.privy.auth.passkey.RegistrationOptions
import io.privy.auth.passkey.toApiFormat
import io.privy.auth.passkey.toNative
import io.privy.auth.session.AuthSessionResponseDeserializer
import io.privy.auth.session.internal.AuthSessionResponse
import io.privy.auth.session.internal.MapRawAuthSessionResponseToAuthSessionResponse
import io.privy.auth.session.internal.toInternalPrivyUser
import io.privy.auth.siwe.toInternalSiweMessage
import io.privy.auth.siwe.GenerateSiweMessageResponse
import io.privy.auth.siwe.InternalSiweMessage
import io.privy.auth.siwe.SiweLoginParams
import io.privy.logging.PrivyLogger
import io.privy.network.ApiResult
import io.privy.network.AuthType
import io.privy.network.KtorWrapper
import io.privy.network.map
import kotlinx.serialization.Serializable
import kotlinx.serialization.json.Json
import kotlinx.serialization.json.JsonElement
import kotlinx.serialization.json.encodeToJsonElement
import me.tatarka.inject.annotations.Inject

@Inject
public class RealAuthRepository(
  private val ktorWrapper: KtorWrapper,
  private val privyLogger: PrivyLogger,
  private val authSessionResponseDeserializer: AuthSessionResponseDeserializer,
  private val mapRawAuthSessionResponseToAuthSessionResponse:
        MapRawAuthSessionResponseToAuthSessionResponse,
) : AuthRepository {
  override suspend fun authenticate(loginType: LoginType): ApiResult<AuthSessionResponse> {
    val authenticateResponse: ApiResult<String> = when (loginType) {
        is LoginType.PasskeyRegistration -> {
            // passkey registration uses a different endpoint than other login methods
            authenticatePasskeyRegistration(loginType)
        }
        is LoginType.PasskeyAuthentication -> {
            // passkey authentication has a different request body structure
            authenticatePasskeyAuthentication(loginType)
        }
        else -> {
            // all other login methods use the standard authenticate endpoint
            ktorWrapper.postResult<AuthenticateResource, Map<String, String>, String>(
                resource = AuthenticateResource(loginTypeApiPath = loginType.apiPath()),
                body = loginType.requestBody(),
                authType = AuthType.None,
            )
        }
    }

    return convertAuthResponseToInternalSession(
        authResponse = authenticateResponse,
        loginMethod = loginType.toLoginMethod(),
    )
  }

  private suspend fun authenticatePasskeyRegistration(
      loginType: LoginType.PasskeyRegistration
  ): ApiResult<String> {
    return ktorWrapper.postResult<PasskeyRegisterResource, PasskeyRegisterRequest, String>(
        resource = PasskeyRegisterResource,
        body = PasskeyRegisterRequest(
            authenticatorResponse = loginType.credential.toApiFormat(),
            relyingParty = loginType.relyingParty
        ),
        authType = AuthType.None,
    )
  }

  private suspend fun authenticatePasskeyAuthentication(
      loginType: LoginType.PasskeyAuthentication
  ): ApiResult<String> {
    return ktorWrapper.postResult<AuthenticateResource, PasskeyAuthenticateRequest, String>(
        resource = AuthenticateResource(loginTypeApiPath = loginType.apiPath()),
        body = PasskeyAuthenticateRequest(
            authenticatorResponse = loginType.credential.toApiFormat(),
            challenge = loginType.challenge,
            relyingParty = loginType.relyingParty
        ),
        authType = AuthType.None,
    )
  }

    override suspend fun generateOAuthUrl(
        oAuthInitRequest: OAuthInitRequest
    ): ApiResult<OAuthInitResponse> {
        return ktorWrapper
            .postResult<OauthInitResource, Map<String, String>, OAuthInitResponse>(
                resource = OauthInitResource,
                body = mapOf(
                    "provider" to oAuthInitRequest.provider.toRequestBody(),
                    "redirect_to" to oAuthInitRequest.redirectUri,
                    "code_challenge" to oAuthInitRequest.codeChallenge,
                    "state_code" to oAuthInitRequest.stateCode
                ),
                authType = AuthType.None
            )
    }


    override suspend fun link(loginType: LoginType, authToken: String): ApiResult<InternalPrivyUser> {
    return ktorWrapper
        .postResult<LinkAccountResource, Map<String, String>, String>(
            resource = LinkAccountResource(loginTypeApiPath = loginType.apiPath()),
            body = loginType.requestBody(),
            authType = AuthType.Authorization(accessToken = authToken),
        )
        .map { jsonResponse ->
          authSessionResponseDeserializer.deserializeRawUser(jsonResponse = jsonResponse)
        }
        .map { it.toInternalPrivyUser() }
  }

  override suspend fun update(
    accountType: UpdateAccountType,
    authToken: String
  ): ApiResult<InternalPrivyUser> {
    return ktorWrapper
      .postResult<UpdateAccountResource, Map<String, String>, String>(
        resource = UpdateAccountResource(updateAccountApiPath = accountType.apiPath()),
        body = accountType.requestBody(),
        authType = AuthType.Authorization(accessToken = authToken),
      )
      .map { jsonResponse ->
        authSessionResponseDeserializer.deserializeRawUser(jsonResponse = jsonResponse)
      }
      .map { it.toInternalPrivyUser() }
  }

  override suspend fun generateSiweMessage(walletAddress: String): ApiResult<InternalSiweMessage> {

    return ktorWrapper
        .postResult<SiweInitResource, Map<String, String>, GenerateSiweMessageResponse>(
            resource = SiweInitResource,
            body = mapOf("address" to walletAddress),
            authType = AuthType.None,
        )
        .map { it.toInternalSiweMessage() }
  }

  override suspend fun refreshSession(
      authToken: String,
      refreshToken: String,
      currentLoginMethod: LoginMethod,
  ): ApiResult<AuthSessionResponse> {
    val refreshResponse: ApiResult<String> =
        ktorWrapper.postResult(
            resource = RefreshSessionResource,
            body = mapOf("refresh_token" to refreshToken),
            authType = AuthType.Authorization(accessToken = authToken),
        )

    return convertAuthResponseToInternalSession(
        authResponse = refreshResponse,
        loginMethod = currentLoginMethod,
    )
  }

  override suspend fun refreshUser(authToken: String): ApiResult<InternalPrivyUser> {
    return ktorWrapper
        .getResult<RefreshUserResource, String>(
            resource = RefreshUserResource,
            authType = AuthType.Authorization(accessToken = authToken),
        )
        .map { jsonResponse ->
          privyLogger.internal("users/me response:\n$jsonResponse")
          authSessionResponseDeserializer.deserializeUser(jsonResponse = jsonResponse)
        }
        .map { it.user.toInternalPrivyUser() }
  }

  private fun convertAuthResponseToInternalSession(
      authResponse: ApiResult<String>,
      loginMethod: LoginMethod
  ): ApiResult<AuthSessionResponse> {
    return authResponse.map { jsonResponse ->
          privyLogger.internal("Authenticate API raw JSON response:\n$jsonResponse")

          authSessionResponseDeserializer.deserialize(jsonResponse = jsonResponse)
        }
        .map {
          privyLogger.internal("Authenticate API response: $it")

          mapRawAuthSessionResponseToAuthSessionResponse(
            rawAuthSessionResponse = it,
            loginMethod = loginMethod,
          )
        }
  }

  override suspend fun sendOtp(otpRequestType: OtpRequestType): ApiResult<Unit> {
    val sendOtpRequest = SendOtpResource(otpTypeApiPath = otpRequestType.apiPath())

    val sendOtpResponse: ApiResult<OtpInitResponse> =
        ktorWrapper.postResult(
            resource = sendOtpRequest,
            body = otpRequestType.requestBody(),
            authType = AuthType.None,
        )

    return when (sendOtpResponse) {
      // resurface underlying error
      is ApiResult.Error -> sendOtpResponse
      // translate success response
      is ApiResult.Success -> {
        if (sendOtpResponse.value.success) {
          ApiResult.Success(Unit)
        } else {
          // API should never return success == false, but just in case
          ApiResult.Error.GenericError(
            exception = AuthenticationException("Error sending OTP."),
            humanReadableMessage = "Error sending OTP."
          )
        }
      }
    }
  }

  override suspend fun generatePasskeySignupOptions(relyingParty: String): ApiResult<RegistrationOptions> {
    return ktorWrapper
        .postResult<PasskeyRegisterInitResource, Map<String, String>, ApiRegistrationOptionsResponse>(
            resource = PasskeyRegisterInitResource,
            body = relyingParty.toPasskeyInitRequestBody(),
            authType = AuthType.None,
        )
        .map { it.options.toNative() }
  }

  override suspend fun generatePasskeyAuthenticationOptions(relyingParty: String): ApiResult<AuthenticationOptions> {
    return ktorWrapper
        .postResult<PasskeyAuthenticateInitResource, Map<String, String>, ApiAuthenticationOptionsResponse>(
            resource = PasskeyAuthenticateInitResource,
            body = relyingParty.toPasskeyInitRequestBody(),
            authType = AuthType.None,
        )
        .map { it.options.toNative() }
  }
}

private fun LoginType.toLoginMethod(): LoginMethod {
  return when (this) {
    is LoginType.CustomAccessToken -> LoginMethod.CustomAccessToken
    is LoginType.Sms -> LoginMethod.Sms
    is LoginType.Email -> LoginMethod.Email
    is LoginType.Siwe -> LoginMethod.Siwe
    is LoginType.OAuth -> LoginMethod.Oauth
    is LoginType.PasskeyRegistration -> LoginMethod.Passkey
    is LoginType.PasskeyAuthentication -> LoginMethod.Passkey
  }
}

@Resource("{otpTypeApiPath}/init")
private class SendOtpResource(
    val otpTypeApiPath: String,
)

@Resource("{loginTypeApiPath}/authenticate")
private class AuthenticateResource(
    val loginTypeApiPath: String,
)

@Resource("{loginTypeApiPath}/link")
private class LinkAccountResource(
    val loginTypeApiPath: String,
)

@Resource("{updateAccountApiPath}/update")
private class UpdateAccountResource(
  val updateAccountApiPath: String,
)

@Resource("siwe/init") private data object SiweInitResource

@Resource("sessions") private data object RefreshSessionResource

@Resource("users/me") private data object RefreshUserResource

@Resource("oauth/init") private data object OauthInitResource

@Resource("passkeys/register/init") private data object PasskeyRegisterInitResource

@Resource("passkeys/authenticate/init") private data object PasskeyAuthenticateInitResource

@Resource("passkeys/register") private data object PasskeyRegisterResource

private fun LoginType.apiPath(): String {
    return when (this) {
        is CustomAccessToken -> "custom_jwt_account"
        is LoginType.Sms -> "passwordless_sms"
        is LoginType.Email -> "passwordless"
        is LoginType.Siwe -> "siwe"
        is LoginType.OAuth -> "oauth"
        is LoginType.PasskeyRegistration -> "passkeys"
        is LoginType.PasskeyAuthentication -> "passkeys" //Unused
    }
}

private fun UpdateAccountType.apiPath(): String {
  return when (this) {
    is UpdateAccountType.Email -> "passwordless"
    is UpdateAccountType.Sms -> "passwordless_sms"
  }
}

private fun LoginType.requestBody(): Map<String, String> {
    return when (this) {
        is CustomAccessToken -> mapOf("token" to this.token)
        is LoginType.Sms -> mapOf("phoneNumber" to this.phoneNumber, "code" to this.code)
        is LoginType.Email -> mapOf("email" to this.emailAddress, "code" to this.code)
        is LoginType.Siwe -> params.toRequestBody()
        is LoginType.OAuth ->
            mapOf(
                "authorization_code" to authorizationCode,
                "code_verifier" to codeVerifier,
                "state_code" to stateCode
            )
        // Passkey types are handled in their own dedicated methods
        is LoginType.PasskeyAuthentication -> emptyMap<String, String>()
        is LoginType.PasskeyRegistration -> emptyMap<String, String>()
    }
}

private fun UpdateAccountType.requestBody(): Map<String, String> {
  return when (this) {
    is UpdateAccountType.Email -> mapOf(
      "oldAddress" to this.oldEmail,
      "newAddress" to this.newEmail,
      "code" to this.code
    )
      is UpdateAccountType.Sms -> mapOf(
          "old_phone_number" to this.oldPhoneNumber,
          "new_phone_number" to this.newPhoneNumber,
          "code" to this.code
    )
  }
}

private fun OtpRequestType.apiPath(): String {
  return when (this) {
    is OtpRequestType.Email -> "passwordless"
    is OtpRequestType.Phone -> "passwordless_sms"
  }
}

private fun OtpRequestType.requestBody(): Map<String, String> {
  return when (this) {
    is OtpRequestType.Email -> mapOf("email" to this.email)
    is OtpRequestType.Phone -> mapOf("phoneNumber" to this.phone)
  }
}

private fun SiweLoginParams.toRequestBody(): Map<String, String> {
  val body = mutableMapOf("message" to message, "signature" to signature, "chainId" to chainId)
  walletClientType?.let { body["walletClientType"] = it.toString() }
  connectorType?.let { body["connectorType"] = it }
  return body
}

private fun OAuthProvider.toRequestBody(): String = when (this) {
    OAuthProvider.Google -> "google"
    OAuthProvider.Twitter -> "twitter"
    OAuthProvider.Discord -> "discord"
}

private fun String.toPasskeyInitRequestBody(): Map<String, String> = mapOf("relying_party" to this)

@Serializable private data class OtpInitResponse(val success: Boolean)
